<!doctype html>
<html>
<head>
   <meta charset="UTF-8">
   <link rel="shortcut icon" href="favicon.ico">
   <title>UCPA Flaine</title>

   <link rel="stylesheet" href=".style.css">
   <script src=".sorttable.js"></script>
</head>

<body>
<div id="container">
	<h1>UCPA Flaine</h1>

	<table class="sortable">
	    <thead>
		<tr>
			<th>Filename</th>
			<th>Type</th>
			<th>Size</th>
			<th>Date Modified</th>
		</tr>
	    </thead>
	    <tbody>
<?php

class File {
	
	public $hreflink;
	public $name;
	public $type;
    public $typekey;
	public $size;
	public $sizekey;
	public $time;
	public $timekey;
	
	public function is_hidden() {
		return substr($this->name, 0, 1) === '.';
	}
	
	public function html_output() {
		return "
		<tr class='$this->typekey'>
			<td><a href='./$this->hreflink'>$this->name</a></td>
			<td><a href='./$this->hreflink'>$this->type</a></td>
			<td sorttable_customkey='$this->sizekey'><a href='./$this->hreflink'>$this->size</a></td>
			<td sorttable_customkey='$this->timekey'><a href='./$this->hreflink'>$this->time</a></td>
		</tr>";
	}
	
	public function __construct($name) {
		$this->name = $name;
		$this->hreflink = $name;
		
		$this->time = date("M j Y g:i A", filemtime($name));
		$this->timekey = date("YmdHis", filemtime($name));
		
		$this->select_behaviour();
	}
	
	private function pretty_filesize() {
		$this->sizekey = filesize($this->name);
		
		if ($this->sizekey < 1024) {
			$this->size = $this->sizekey." Bytes";
		}
		elseif ( ($this->sizekey < 1048576) && ($this->sizekey > 1023) ) {
			$this->size = round($this->sizekey / 1024, 1)." KB";
		}
		elseif ( ($this->sizekey < 1073741824) && ($this->sizekey > 1048575)) {
			$this->size = round($this->sizekey / 1048576, 1)." MB";
		}
		else {
			$this->size = round($this->sizekey / 1073741824, 1)." GB";
		}
	}
	
	private function select_behaviour() {
		if (is_dir($this->name)) {
			$this->directory_operations();
		}
		elseif (is_link($this->name)) {
			$this->symlink_operations();
		}
		else {
			$this->file_operations();
		}
	}
	
	private function directory_operations() {
		$this->type = '&lt;Directory&gt;';
        $this->typekey = 'dir';
		$this->size = '';
		$this->sizekey = '0';

		if ($this->name == '..') {
			$this->name = '.. (Parent Directory)'; 
			$this->type = '&lt;System Dir&gt;';
		}
	}

	private function file_operations() {
		// Gets file extension
        $this->typekey = strtolower(pathinfo($this->name, PATHINFO_EXTENSION));

		// Prettifies file type
		switch ($this->typekey) {
			case "png":	$this->type = "PNG Image"; break;
			case "jpg": $this->type = "JPEG Image"; break;
			case "jpeg": $this->type = "JPEG Image"; break;
			case "svg": $this->type = "SVG Image"; break;
			case "gif": $this->type = "GIF Image"; break;
			case "ico": $this->type = "Windows Icon"; break;
			
			case "mov": $this->type = "Quicktime Movie"; break;

			case "txt": $this->type = "Text File"; break;
			case "log": $this->type = "Log File"; break;
			case "htm": $this->type = "HTML File"; break;
			case "html": $this->type = "HTML File"; break;
			case "xhtml": $this->type = "HTML File"; break;
			case "shtml": $this->type = "HTML File"; break;
			case "php": $this->type = "PHP Script"; break;
			case "js": $this->type = "Javascript File"; break;
			case "css": $this->type = "Stylesheet"; break;

			case "pdf": $this->type="PDF Document"; break;
			case "xls": $this->type="Spreadsheet"; break;
			case "xlsx": $this->type="Spreadsheet"; break;
			case "doc": $this->type="Microsoft Word Document"; break;
			case "docx": $this->type="Microsoft Word Document"; break;

			case "zip": $this->type = "ZIP Archive"; break;
			case "htaccess": $this->type = "Apache Config File"; break;
			case "exe": $this->type = "Windows Executable"; break;

			default: 
				if ($this->type != "") { 
					$this->type = strtoupper($this->typekey)." File";
				} else { 
					$this->type = "Unknown";
				}
				break;
		}

		// Gets and cleans up file size
		$this->pretty_filesize();
	}

	private function symlink_operations() {
		$this->name = readlink($this->name);
		$this->select_behaviour();
	}
}



// Opens directory
$myDirectory = opendir(".");

// Gets each entry
while ($entryName = readdir($myDirectory)) {
   $dirArray[] = $entryName;
}

// Closes directory
closedir($myDirectory);

// Counts elements in array
$indexCount = count($dirArray);

// Sorts files
sort($dirArray);

// Loops through the array of files
for($index = 0; $index < $indexCount; $index++) {

	$file = new File($dirArray[$index]);
	//$name = $dirArray[$index];

	// Don't display hidden files neither index.php, favicon.ico, robots.txt
	if(!$file->is_hidden() && $file->name !== 'index.php' && $file->name !== 'favicon.ico' && $file->name !== 'robots.txt') {
		echo($file->html_output());
	}
}
?>
	    </tbody>
	</table>
</div>
</body>
</html>
